@@ -36,14 +36,10 @@ sub setRow
 
     my $listModel = $self->listModel();
 
-    my $rows_r = $listModel->rows();
-
-    foreach my $row (@{ $rows_r }) {
-        my $id       = $row->id();
+    foreach my $id (@{ $listModel->ids()}) {
+        my $row = $listModel->row($id);
         my $allowed = $row->elementByName('allowed');
         $allowed->setValue($allowValue);
-
-
         $listModel->setTypedRow($id, { allowed => $allowed } );
     }
     ;
@@ -146,7 +142,7 @@ sub changeRowJS
     $fields =~ s/'/"/g;
 
     my $onCompleteJS =  <<END;
-    function(t) { 
+    function(t) {
         highlightRow( id, false);
         stripe("dataTable", "#ecf5da", "#ffffff");
         $changeViewListJS;
@@ -154,7 +150,7 @@ sub changeRowJS
 END
 
 
-    my $JS = sprintf ($function, 
+    my $JS = sprintf ($function,
             $table->{'actions'}->{'editField'},
             $table->{'tableName'},
             $fields,
